Learn R Programming

snapKrig (version 0.0.2)

anyNA.sk: Check for presence of grid points with missing data (NAs)

Description

Returns a logical indicating if any of the grid points are NA

Usage

# S3 method for sk
anyNA(x, recursive)

Value

logical

Arguments

x

a sk object

recursive

ignored

Examples

Run this code
g = sk_validate(list(gval=stats::rnorm(4^2), gdim=4, gres=0.5))
anyNA(g)
g[1] = NA
anyNA(g)

Run the code above in your browser using DataLab