length.sk: The number of grid-points

View source: R/sk_methods.R

length.skR Documentation

The number of grid-points

Description

Returns the total number of points in the grid, which is the product of the number of y and x grid lines (gdim).

Usage

## S3 method for class 'sk'
length(x)

Arguments

x

a sk object

Value

integer

Examples

g = sk_validate(list(gval=stats::rnorm(4^2), gdim=4, gres=0.5))
length(g)

snapKrig documentation built on July 4, 2026, 5:06 p.m.