| sk_kp | R Documentation |
Convenience function for looking up the number of parameters for a given
Kronecker covariance model, and their names. Returns a vector of NAs that
can be used as a placeholder in kernel definition lists.
sk_kp(k)
k |
character, the kernel name, one of 'exp', 'gau', 'sph', 'gxp', 'mat' |
named vector of NAs, a placeholder for kernel parameters
Other parameter managers:
sk_bds(),
sk_fit(),
sk_pars(),
sk_pars_make(),
sk_pars_update(),
sk_to_string()
# there are only two possible return values
sk_kp('gau')
sk_kp('mat')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.