| sk_pars | R Documentation |
Returns a parameter list defining the Kronecker covariance model for g, with
default initial values assigned to parameters based on the grid dimensions and sample
variance of observed data.
sk_pars(g, pars = "gau", fill = "initial")
g |
list, a sk grid list (or any other object accepted by |
pars |
character or list defining kernels accepted by |
fill |
character, either 'initial', 'lower' or 'upper' |
Swap fill='initial' with 'lower' and 'upper' to get default lower and upper bounds.
a list defining the Kronecker covariance parameters
sk sk_corr
Other parameter managers:
sk_bds(),
sk_fit(),
sk_kp(),
sk_pars_make(),
sk_pars_update(),
sk_to_string()
sk_pars(g=10)
sk_pars(c(10,15))
sk_pars(c(10,15), 'mat')
sk_pars(c(10,15), 'mat', 'upper')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.