subset-.sk: Single-bracket assign

[<-.skR Documentation

Single-bracket assign

Description

Behavior depends on the class of i. For character vectors, this assigns to the named list entries of x (as usual). For numeric indices, it assigns vectorized grid data values. For multi-layer objects, specify the layer in j and supply a matrix for replacement

Usage

## S3 replacement method for class 'sk'
x[i = NULL, j = NULL] <- value

Arguments

x

an sk object

i

column-vectorized index

j

index of layer (only for multi-layer x)

value

the replacement values

Value

the "sk" object with the specified subset replaced by value

Examples

g = sk_validate(list(gval=stats::rnorm(4^2), gdim=4, gres=0.5))
print(g)
g[1] = NA
print(g)


snapKrig documentation built on July 4, 2026, 5:06 p.m.