Learn R Programming

snapKrig (version 0.0.2)

sk_kp: Return named vector of Kronecker covariance parameters initialized to NA

Description

Convenience function for looking up the number of parameters for a given Kronecker covariance model, and their names. Returns a vector of NAs that can be used as a placeholder in kernel definition lists.

Usage

sk_kp(k)

Value

named vector of NAs, a placeholder for kernel parameters

Arguments

k

character, the kernel name, one of 'exp', 'gau', 'sph', 'gxp', 'mat'

See Also

Other parameter managers: sk_bds(), sk_fit(), sk_pars_make(), sk_pars_update(), sk_pars(), sk_to_string()

Examples

Run this code

# there are only two possible return values
sk_kp('gau')
sk_kp('mat')

Run the code above in your browser using DataLab